[![](https://codecov.io/gh/nickderobertis/flexlate-dev/branch/master/graph/badge.svg)](https://codecov.io/gh/nickderobertis/flexlate-dev)

#  flexlate-dev

## Overview

Development tools for template authors using Flexlate

## Getting Started

Install `flexlate-dev`:

```
pip install flexlate-dev
```

A simple example:

```python
import flexlate_dev

# Do something with flexlate_dev
```

## Links

See the
[documentation here.](
https://nickderobertis.github.io/flexlate-dev/
)

## Development Status

This project is currently in early-stage development. There may be
breaking changes often. While the major version is 0, minor version
upgrades will often have breaking changes.

## Author

Created by Nick DeRobertis. MIT License.
